SystemOrganization addCategory: #'Seaside-Adaptors-Hyper'!

WABaseServerAdaptor subclass: #WAHyperAdaptor
	instanceVariableNames: 'server'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Adaptors-Hyper'!

!WAHyperAdaptor commentStamp: 'pmm 1/1/2009 20:06' prior: 0!
A WAHyperAdaptor makes Seaside run on Hyper.

Instance Variables
	server:		<HTTPServer>

server
	- The Hyper HTTP server
!

!WAHyperAdaptor methodsFor: 'private-controlling' stamp: 'pmm 1/1/2009 20:04'!
basicStart
	server portNumber: self port.
	server start! !

!WAHyperAdaptor methodsFor: 'private-controlling' stamp: 'pmm 1/1/2009 20:05'!
basicStop
	server stop! !

!WAHyperAdaptor methodsFor: 'private-converting' stamp: 'pmm 1/1/2009 22:38'!
convertCookiesFrom: aWAResonse to: aNativeResponse
	aWAResonse do: [ :each |
		aNativeResponse cookie: each oldNetscapeString ]! !

!WAHyperAdaptor methodsFor: 'initialize-release' stamp: 'pmm 1/1/2009 22:40'!
initialize
	super initialize.
	server := HTTPServer new.
	server multiThreading: true.
	"Use MessageSend instead of blocks because Squeak is gayer than AIDS"
	server responseBlock: (MessageSend
		receiver: self 
		selector: #handleRequest:).
	server internalErrorHandler: (MessageSend
		receiver: self
		selector: #internalErrorResponseFor:)! !

!WAHyperAdaptor methodsFor: 'testing' stamp: 'pmm 1/1/2009 20:10'!
isRunning
	^server isStarted! !

!WAHyperAdaptor methodsFor: 'testing' stamp: 'pmm 1/1/2009 20:12'!
isStarting
	^false! !

!WAHyperAdaptor methodsFor: 'testing' stamp: 'pmm 1/1/2009 20:11'!
isStopped
	^server isStarted not! !

!WAHyperAdaptor methodsFor: 'testing' stamp: 'pmm 1/1/2009 20:11'!
isStopping
	^server isStopping! !

!WAHyperAdaptor methodsFor: 'private-controlling' stamp: 'pmm 1/1/2009 20:06'!
shutDown
	HTTPServer shutDown! !

WABaseServerAdaptor subclass: #WASoHServerAdaptor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Adaptors-Hyper'!

!WASoHServerAdaptor commentStamp: 'pmm 1/1/2009 22:29' prior: 0!
A WASoHServerAdaptor is the base adapter class for Swazoo or Hyper server adaptors.
!

!WASoHServerAdaptor methodsFor: 'private-converting' stamp: 'pmm 1/1/2009 22:35'!
convertCookiesFrom: aWAResonse to: aNativeResponse
	self subclassResponsibility! !

!WASoHServerAdaptor methodsFor: 'private-converting' stamp: 'pmm 1/1/2009 22:34'!
convertHeader: aSwazooRequest
	| swazooFields fields |
	swazooFields := aSwazooRequest headers fields.
	fields := Dictionary new: swazooFields size.
	swazooFields keysAndValuesDo: [ :key :field |
		| value |
		value := String streamContents: [ :stream |
			field valuesAsStringOn: stream ].
		fields at: key asLowercase put: value ].
	^fields! !

!WASoHServerAdaptor methodsFor: 'private-converting' stamp: 'pmm 1/1/2009 22:35'!
convertResponse: aSeasideResponse
	| swazooResponse |
	aSeasideResponse isNil
		ifTrue:  [ ^self requestHandlingAborted ].
	swazooResponse := HTTPResponse new.
			
	aSeasideResponse headers do: [ :each |
		| field fieldClass |
		fieldClass := HeaderField classForFieldName: each key.
		field := fieldClass newForFieldName: each key withValueFrom: each value.
		swazooResponse headers addField: field ].
	self convertCookiesFrom: aSeasideResponse to: swazooResponse.
	
	swazooResponse code: aSeasideResponse status asNumber.
	swazooResponse entity: (self contentsOfResponse: aSeasideResponse).
	swazooResponse contentType: aSeasideResponse contentType seasideString.
	^swazooResponse! !

!WASoHServerAdaptor methodsFor: 'private' stamp: 'pmm 1/1/2009 22:31'!
cookiesFrom: aSwazooRequest
	^WARequestCookie fromString: aSwazooRequest cookie! !

!WASoHServerAdaptor methodsFor: 'private' stamp: 'pmm 1/1/2009 22:31'!
getFieldsOf: aSwazooRequest into: aDictionaryMerger
	aSwazooRequest queries do: [ :each |
		aDictionaryMerger at: each key put: (self decodeUrl: each value) ]! !

!WASoHServerAdaptor methodsFor: 'private-response-creation' stamp: 'pmm 1/1/2009 22:35'!
internalErrorResponseFor: anError
	^HTTPResponse internalServerError
		entity: 'Internal Error';
		yourself! !

!WASoHServerAdaptor methodsFor: 'private' stamp: 'pmm 1/1/2009 22:32'!
methodNameOf: aNativeRequest
	^aNativeRequest methodName! !

!WASoHServerAdaptor methodsFor: 'private' stamp: 'pmm 1/1/2009 22:34'!
postFieldsOf: aNativeRequest into: aDictionaryMerger
	"break encapsulation"
	aNativeRequest ensureFullRead.
	aNativeRequest postData keysAndValuesDo: [ :key :value |
		| previousData data |
		data := value filename isEmptyOrNil
			ifTrue: [ self decodeUrl: value value ]
			ifFalse: [
				WAFile new
					fileName: (self decodeUrl: value filename);
					contentType: value contentType seasideMimeType;
					contents: value value;
					yourself ].
		aDictionaryMerger at: key put: data ]! !

!WASoHServerAdaptor methodsFor: 'private' stamp: 'pmm 1/1/2009 22:32'!
remoteAddressOf: aSwazooRequest
	"converts a Squeak address (ByteArray) to an IPv4 String"
	| remoteAddress |
	remoteAddress := aSwazooRequest peer.
	remoteAddress isString ifTrue: [
		"so apparently someone has a new VM with IPv6 support"
		^remoteAddress ].
	
	^String streamContents: [ :stream |
		remoteAddress
			do: [ :each | stream print: each ]
			separatedBy: [ stream nextPut: $. ] ]! !

!WASoHServerAdaptor methodsFor: 'accessing' stamp: 'pmm 1/1/2009 22:29'!
statusString
	^self isRunning
		ifTrue: [ 'running' ]
		ifFalse: [ 'stopped' ]! !

!WASoHServerAdaptor methodsFor: 'private' stamp: 'pmm 1/1/2009 22:34'!
urlFrom: aSwazooRequest
	^((WAUrl absolute: aSwazooRequest uri printString)
		decodedWith: self codec) withoutParameters! !
